NavBarEssentials class

Constructors

const

Properties

backgroundColor → Color?
final
hashCode → int
The hash code for this object.
no setterinherited
itemAnimationProperties → ItemAnimationProperties?
final
items → List<PersistentBottomNavBarItem>?
final
final
onItemSelected → ValueChanged<int>?
final
padding → NavBarPadding?
final
popScreensOnTapOfSelectedTab → bool?
final
previousIndex → int?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
selectedIndex → int?
final
selectedScreenBuildContext → BuildContext?
final

Methods

copyWith({int? selectedIndex, int? previousIndex, double? iconSize, Color? backgroundColor, List<PersistentBottomNavBarItem>? items, ValueChanged<int>? onItemSelected, double? navBarHeight, NavBarPadding? padding, dynamic popAllScreensForTheSelectedTab(int)?, bool? popScreensOnTapOfSelectedTab, ItemAnimationProperties? itemAnimationProperties}) → NavBarEssentials
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited