PersistentBottomNavBar class

Inheritance

Constructors

PersistentBottomNavBar({Key? key, EdgeInsets? margin, bool? confineToSafeArea, Widget? customNavBarWidget, bool? hideNavigationBar, dynamic onAnimationComplete(bool, bool)?, NeumorphicProperties? neumorphicProperties = const NeumorphicProperties(), NavBarEssentials? navBarEssentials, NavBarDecoration? navBarDecoration, NavBarStyle? navBarStyle, bool? isCustomWidget = false})
const

Properties

confineToSafeArea → bool?
final
customNavBarWidget → Widget?
final
hashCode → int
The hash code for this object.
no setterinherited
hideNavigationBar → bool?
final
isCustomWidget → bool?
final
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
margin → EdgeInsets?
final
final
final
final
neumorphicProperties → NeumorphicProperties?
final
onAnimationComplete → dynamic Function(bool, bool)?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

build(BuildContext context) → Widget
Describes the part of the user interface represented by this widget.
override
copyWith({int? selectedIndex, double? iconSize, int? previousIndex, Color? backgroundColor, Duration? animationDuration, List<PersistentBottomNavBarItem>? items, ValueChanged<int>? onItemSelected, double? navBarHeight, EdgeInsets? margin, NavBarStyle? navBarStyle, double? horizontalPadding, NeumorphicProperties? neumorphicProperties, Widget? customNavBarWidget, dynamic popAllScreensForTheSelectedTab(int)?, bool? popScreensOnTapOfSelectedTab, NavBarDecoration? navBarDecoration, NavBarEssentials? navBarEssentials, bool? confineToSafeArea, ItemAnimationProperties? itemAnimationProperties, Function? onAnimationComplete, bool? hideNavigationBar, bool? isCustomWidget, EdgeInsets? padding}) → PersistentBottomNavBar
createElement() → StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
getNavBarStyle() → Widget?
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
opaque(int? index) → bool
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited