onWillPop property

Future<bool> Function(BuildContext?)? onWillPop
final

If you want to perform a custom action on Android when exiting the app, you can write your logic here. Returns context of the selected screen.

Implementation

final Future<bool> Function(BuildContext?)? onWillPop;